// java wrapper for vtkRenderer object
//

package vtk;
import vtk.*;

public class vtkRenderer extends vtkViewport
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void AddActor_2(vtkProp id0);
  public void AddActor(vtkProp id0)
    { AddActor_2(id0); }

  private native void AddVolume_3(vtkProp id0);
  public void AddVolume(vtkProp id0)
    { AddVolume_3(id0); }

  private native void RemoveActor_4(vtkProp id0);
  public void RemoveActor(vtkProp id0)
    { RemoveActor_4(id0); }

  private native void RemoveVolume_5(vtkProp id0);
  public void RemoveVolume(vtkProp id0)
    { RemoveVolume_5(id0); }

  private native void AddLight_6(vtkLight id0);
  public void AddLight(vtkLight id0)
    { AddLight_6(id0); }

  private native void RemoveLight_7(vtkLight id0);
  public void RemoveLight(vtkLight id0)
    { RemoveLight_7(id0); }

  private native void RemoveAllLights_8();
  public void RemoveAllLights()
    { RemoveAllLights_8(); }

  private native long GetLights_9();
  public vtkLightCollection GetLights() {
    long temp = GetLights_9();

    if (temp == 0) return null;
    return (vtkLightCollection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetLightCollection_10(vtkLightCollection id0);
  public void SetLightCollection(vtkLightCollection id0)
    { SetLightCollection_10(id0); }

  private native void CreateLight_11();
  public void CreateLight()
    { CreateLight_11(); }

  private native long MakeLight_12();
  public vtkLight MakeLight() {
    long temp = MakeLight_12();

    if (temp == 0) return null;
    return (vtkLight)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetTwoSidedLighting_13();
  public int GetTwoSidedLighting()
    { return GetTwoSidedLighting_13(); }

  private native void SetTwoSidedLighting_14(int id0);
  public void SetTwoSidedLighting(int id0)
    { SetTwoSidedLighting_14(id0); }

  private native void TwoSidedLightingOn_15();
  public void TwoSidedLightingOn()
    { TwoSidedLightingOn_15(); }

  private native void TwoSidedLightingOff_16();
  public void TwoSidedLightingOff()
    { TwoSidedLightingOff_16(); }

  private native void SetLightFollowCamera_17(int id0);
  public void SetLightFollowCamera(int id0)
    { SetLightFollowCamera_17(id0); }

  private native int GetLightFollowCamera_18();
  public int GetLightFollowCamera()
    { return GetLightFollowCamera_18(); }

  private native void LightFollowCameraOn_19();
  public void LightFollowCameraOn()
    { LightFollowCameraOn_19(); }

  private native void LightFollowCameraOff_20();
  public void LightFollowCameraOff()
    { LightFollowCameraOff_20(); }

  private native int GetAutomaticLightCreation_21();
  public int GetAutomaticLightCreation()
    { return GetAutomaticLightCreation_21(); }

  private native void SetAutomaticLightCreation_22(int id0);
  public void SetAutomaticLightCreation(int id0)
    { SetAutomaticLightCreation_22(id0); }

  private native void AutomaticLightCreationOn_23();
  public void AutomaticLightCreationOn()
    { AutomaticLightCreationOn_23(); }

  private native void AutomaticLightCreationOff_24();
  public void AutomaticLightCreationOff()
    { AutomaticLightCreationOff_24(); }

  private native int UpdateLightsGeometryToFollowCamera_25();
  public int UpdateLightsGeometryToFollowCamera()
    { return UpdateLightsGeometryToFollowCamera_25(); }

  private native long GetVolumes_26();
  public vtkVolumeCollection GetVolumes() {
    long temp = GetVolumes_26();

    if (temp == 0) return null;
    return (vtkVolumeCollection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetActors_27();
  public vtkActorCollection GetActors() {
    long temp = GetActors_27();

    if (temp == 0) return null;
    return (vtkActorCollection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetActiveCamera_28(vtkCamera id0);
  public void SetActiveCamera(vtkCamera id0)
    { SetActiveCamera_28(id0); }

  private native long GetActiveCamera_29();
  public vtkCamera GetActiveCamera() {
    long temp = GetActiveCamera_29();

    if (temp == 0) return null;
    return (vtkCamera)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long MakeCamera_30();
  public vtkCamera MakeCamera() {
    long temp = MakeCamera_30();

    if (temp == 0) return null;
    return (vtkCamera)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetErase_31(int id0);
  public void SetErase(int id0)
    { SetErase_31(id0); }

  private native int GetErase_32();
  public int GetErase()
    { return GetErase_32(); }

  private native void EraseOn_33();
  public void EraseOn()
    { EraseOn_33(); }

  private native void EraseOff_34();
  public void EraseOff()
    { EraseOff_34(); }

  private native void SetDraw_35(int id0);
  public void SetDraw(int id0)
    { SetDraw_35(id0); }

  private native int GetDraw_36();
  public int GetDraw()
    { return GetDraw_36(); }

  private native void DrawOn_37();
  public void DrawOn()
    { DrawOn_37(); }

  private native void DrawOff_38();
  public void DrawOff()
    { DrawOff_38(); }

  private native int CaptureGL2PSSpecialProp_39(vtkProp id0);
  public int CaptureGL2PSSpecialProp(vtkProp id0)
    { return CaptureGL2PSSpecialProp_39(id0); }

  private native void SetGL2PSSpecialPropCollection_40(vtkPropCollection id0);
  public void SetGL2PSSpecialPropCollection(vtkPropCollection id0)
    { SetGL2PSSpecialPropCollection_40(id0); }

  private native void AddCuller_41(vtkCuller id0);
  public void AddCuller(vtkCuller id0)
    { AddCuller_41(id0); }

  private native void RemoveCuller_42(vtkCuller id0);
  public void RemoveCuller(vtkCuller id0)
    { RemoveCuller_42(id0); }

  private native long GetCullers_43();
  public vtkCullerCollection GetCullers() {
    long temp = GetCullers_43();

    if (temp == 0) return null;
    return (vtkCullerCollection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetAmbient_44(double id0,double id1,double id2);
  public void SetAmbient(double id0,double id1,double id2)
    { SetAmbient_44(id0,id1,id2); }

  private native void SetAmbient_45(double id0[]);
  public void SetAmbient(double id0[])
    { SetAmbient_45(id0); }

  private native double[] GetAmbient_46();
  public double[] GetAmbient()
    { return GetAmbient_46(); }

  private native void SetAllocatedRenderTime_47(double id0);
  public void SetAllocatedRenderTime(double id0)
    { SetAllocatedRenderTime_47(id0); }

  private native double GetAllocatedRenderTime_48();
  public double GetAllocatedRenderTime()
    { return GetAllocatedRenderTime_48(); }

  private native double GetTimeFactor_49();
  public double GetTimeFactor()
    { return GetTimeFactor_49(); }

  private native void Render_50();
  public void Render()
    { Render_50(); }

  private native void DeviceRender_51();
  public void DeviceRender()
    { DeviceRender_51(); }

  private native void DeviceRenderOpaqueGeometry_52();
  public void DeviceRenderOpaqueGeometry()
    { DeviceRenderOpaqueGeometry_52(); }

  private native void DeviceRenderTranslucentPolygonalGeometry_53();
  public void DeviceRenderTranslucentPolygonalGeometry()
    { DeviceRenderTranslucentPolygonalGeometry_53(); }

  private native void ClearLights_54();
  public void ClearLights()
    { ClearLights_54(); }

  private native void Clear_55();
  public void Clear()
    { Clear_55(); }

  private native int VisibleActorCount_56();
  public int VisibleActorCount()
    { return VisibleActorCount_56(); }

  private native int VisibleVolumeCount_57();
  public int VisibleVolumeCount()
    { return VisibleVolumeCount_57(); }

  private native void ComputeVisiblePropBounds_58(double id0[]);
  public void ComputeVisiblePropBounds(double id0[])
    { ComputeVisiblePropBounds_58(id0); }

  private native double[] ComputeVisiblePropBounds_59();
  public double[] ComputeVisiblePropBounds()
    { return ComputeVisiblePropBounds_59(); }

  private native void ResetCameraClippingRange_60();
  public void ResetCameraClippingRange()
    { ResetCameraClippingRange_60(); }

  private native void ResetCameraClippingRange_61(double id0[]);
  public void ResetCameraClippingRange(double id0[])
    { ResetCameraClippingRange_61(id0); }

  private native void ResetCameraClippingRange_62(double id0,double id1,double id2,double id3,double id4,double id5);
  public void ResetCameraClippingRange(double id0,double id1,double id2,double id3,double id4,double id5)
    { ResetCameraClippingRange_62(id0,id1,id2,id3,id4,id5); }

  private native void SetNearClippingPlaneTolerance_63(double id0);
  public void SetNearClippingPlaneTolerance(double id0)
    { SetNearClippingPlaneTolerance_63(id0); }

  private native double GetNearClippingPlaneToleranceMinValue_64();
  public double GetNearClippingPlaneToleranceMinValue()
    { return GetNearClippingPlaneToleranceMinValue_64(); }

  private native double GetNearClippingPlaneToleranceMaxValue_65();
  public double GetNearClippingPlaneToleranceMaxValue()
    { return GetNearClippingPlaneToleranceMaxValue_65(); }

  private native double GetNearClippingPlaneTolerance_66();
  public double GetNearClippingPlaneTolerance()
    { return GetNearClippingPlaneTolerance_66(); }

  private native void SetClippingRangeExpansion_67(double id0);
  public void SetClippingRangeExpansion(double id0)
    { SetClippingRangeExpansion_67(id0); }

  private native double GetClippingRangeExpansionMinValue_68();
  public double GetClippingRangeExpansionMinValue()
    { return GetClippingRangeExpansionMinValue_68(); }

  private native double GetClippingRangeExpansionMaxValue_69();
  public double GetClippingRangeExpansionMaxValue()
    { return GetClippingRangeExpansionMaxValue_69(); }

  private native double GetClippingRangeExpansion_70();
  public double GetClippingRangeExpansion()
    { return GetClippingRangeExpansion_70(); }

  private native void ResetCamera_71();
  public void ResetCamera()
    { ResetCamera_71(); }

  private native void ResetCamera_72(double id0[]);
  public void ResetCamera(double id0[])
    { ResetCamera_72(id0); }

  private native void ResetCamera_73(double id0,double id1,double id2,double id3,double id4,double id5);
  public void ResetCamera(double id0,double id1,double id2,double id3,double id4,double id5)
    { ResetCamera_73(id0,id1,id2,id3,id4,id5); }

  private native void SetRenderWindow_74(vtkRenderWindow id0);
  public void SetRenderWindow(vtkRenderWindow id0)
    { SetRenderWindow_74(id0); }

  private native long GetRenderWindow_75();
  public vtkRenderWindow GetRenderWindow() {
    long temp = GetRenderWindow_75();

    if (temp == 0) return null;
    return (vtkRenderWindow)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetVTKWindow_76();
  public vtkWindow GetVTKWindow() {
    long temp = GetVTKWindow_76();

    if (temp == 0) return null;
    return (vtkWindow)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetBackingStore_77(int id0);
  public void SetBackingStore(int id0)
    { SetBackingStore_77(id0); }

  private native int GetBackingStore_78();
  public int GetBackingStore()
    { return GetBackingStore_78(); }

  private native void BackingStoreOn_79();
  public void BackingStoreOn()
    { BackingStoreOn_79(); }

  private native void BackingStoreOff_80();
  public void BackingStoreOff()
    { BackingStoreOff_80(); }

  private native void SetInteractive_81(int id0);
  public void SetInteractive(int id0)
    { SetInteractive_81(id0); }

  private native int GetInteractive_82();
  public int GetInteractive()
    { return GetInteractive_82(); }

  private native void InteractiveOn_83();
  public void InteractiveOn()
    { InteractiveOn_83(); }

  private native void InteractiveOff_84();
  public void InteractiveOff()
    { InteractiveOff_84(); }

  private native void SetLayer_85(int id0);
  public void SetLayer(int id0)
    { SetLayer_85(id0); }

  private native int GetLayer_86();
  public int GetLayer()
    { return GetLayer_86(); }

  private native int GetPreserveColorBuffer_87();
  public int GetPreserveColorBuffer()
    { return GetPreserveColorBuffer_87(); }

  private native void SetPreserveColorBuffer_88(int id0);
  public void SetPreserveColorBuffer(int id0)
    { SetPreserveColorBuffer_88(id0); }

  private native void PreserveColorBufferOn_89();
  public void PreserveColorBufferOn()
    { PreserveColorBufferOn_89(); }

  private native void PreserveColorBufferOff_90();
  public void PreserveColorBufferOff()
    { PreserveColorBufferOff_90(); }

  private native void SetPreserveDepthBuffer_91(int id0);
  public void SetPreserveDepthBuffer(int id0)
    { SetPreserveDepthBuffer_91(id0); }

  private native int GetPreserveDepthBuffer_92();
  public int GetPreserveDepthBuffer()
    { return GetPreserveDepthBuffer_92(); }

  private native void PreserveDepthBufferOn_93();
  public void PreserveDepthBufferOn()
    { PreserveDepthBufferOn_93(); }

  private native void PreserveDepthBufferOff_94();
  public void PreserveDepthBufferOff()
    { PreserveDepthBufferOff_94(); }

  private native int Transparent_95();
  public int Transparent()
    { return Transparent_95(); }

  private native void WorldToView_96();
  public void WorldToView()
    { WorldToView_96(); }

  private native void ViewToWorld_97();
  public void ViewToWorld()
    { ViewToWorld_97(); }

  private native double GetZ_98(int id0,int id1);
  public double GetZ(int id0,int id1)
    { return GetZ_98(id0,id1); }

  private native int GetMTime_99();
  public int GetMTime()
    { return GetMTime_99(); }

  private native double GetLastRenderTimeInSeconds_100();
  public double GetLastRenderTimeInSeconds()
    { return GetLastRenderTimeInSeconds_100(); }

  private native int GetNumberOfPropsRendered_101();
  public int GetNumberOfPropsRendered()
    { return GetNumberOfPropsRendered_101(); }

  private native long PickProp_102(double id0,double id1);
  public vtkAssemblyPath PickProp(double id0,double id1) {
    long temp = PickProp_102(id0,id1);

    if (temp == 0) return null;
    return (vtkAssemblyPath)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long PickProp_103(double id0,double id1,double id2,double id3);
  public vtkAssemblyPath PickProp(double id0,double id1,double id2,double id3) {
    long temp = PickProp_103(id0,id1,id2,id3);

    if (temp == 0) return null;
    return (vtkAssemblyPath)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void StereoMidpoint_104();
  public void StereoMidpoint()
    { StereoMidpoint_104(); }

  private native double GetTiledAspectRatio_105();
  public double GetTiledAspectRatio()
    { return GetTiledAspectRatio_105(); }

  private native int IsActiveCameraCreated_106();
  public int IsActiveCameraCreated()
    { return IsActiveCameraCreated_106(); }

  private native void SetUseDepthPeeling_107(int id0);
  public void SetUseDepthPeeling(int id0)
    { SetUseDepthPeeling_107(id0); }

  private native int GetUseDepthPeeling_108();
  public int GetUseDepthPeeling()
    { return GetUseDepthPeeling_108(); }

  private native void UseDepthPeelingOn_109();
  public void UseDepthPeelingOn()
    { UseDepthPeelingOn_109(); }

  private native void UseDepthPeelingOff_110();
  public void UseDepthPeelingOff()
    { UseDepthPeelingOff_110(); }

  private native void SetUseDepthPeelingForVolumes_111(boolean id0);
  public void SetUseDepthPeelingForVolumes(boolean id0)
    { SetUseDepthPeelingForVolumes_111(id0); }

  private native boolean GetUseDepthPeelingForVolumes_112();
  public boolean GetUseDepthPeelingForVolumes()
    { return GetUseDepthPeelingForVolumes_112(); }

  private native void UseDepthPeelingForVolumesOn_113();
  public void UseDepthPeelingForVolumesOn()
    { UseDepthPeelingForVolumesOn_113(); }

  private native void UseDepthPeelingForVolumesOff_114();
  public void UseDepthPeelingForVolumesOff()
    { UseDepthPeelingForVolumesOff_114(); }

  private native void SetOcclusionRatio_115(double id0);
  public void SetOcclusionRatio(double id0)
    { SetOcclusionRatio_115(id0); }

  private native double GetOcclusionRatioMinValue_116();
  public double GetOcclusionRatioMinValue()
    { return GetOcclusionRatioMinValue_116(); }

  private native double GetOcclusionRatioMaxValue_117();
  public double GetOcclusionRatioMaxValue()
    { return GetOcclusionRatioMaxValue_117(); }

  private native double GetOcclusionRatio_118();
  public double GetOcclusionRatio()
    { return GetOcclusionRatio_118(); }

  private native void SetMaximumNumberOfPeels_119(int id0);
  public void SetMaximumNumberOfPeels(int id0)
    { SetMaximumNumberOfPeels_119(id0); }

  private native int GetMaximumNumberOfPeels_120();
  public int GetMaximumNumberOfPeels()
    { return GetMaximumNumberOfPeels_120(); }

  private native int GetLastRenderingUsedDepthPeeling_121();
  public int GetLastRenderingUsedDepthPeeling()
    { return GetLastRenderingUsedDepthPeeling_121(); }

  private native void SetDelegate_122(vtkRendererDelegate id0);
  public void SetDelegate(vtkRendererDelegate id0)
    { SetDelegate_122(id0); }

  private native long GetDelegate_123();
  public vtkRendererDelegate GetDelegate() {
    long temp = GetDelegate_123();

    if (temp == 0) return null;
    return (vtkRendererDelegate)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetSelector_124();
  public vtkHardwareSelector GetSelector() {
    long temp = GetSelector_124();

    if (temp == 0) return null;
    return (vtkHardwareSelector)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetBackgroundTexture_125(vtkTexture id0);
  public void SetBackgroundTexture(vtkTexture id0)
    { SetBackgroundTexture_125(id0); }

  private native long GetBackgroundTexture_126();
  public vtkTexture GetBackgroundTexture() {
    long temp = GetBackgroundTexture_126();

    if (temp == 0) return null;
    return (vtkTexture)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetTexturedBackground_127(boolean id0);
  public void SetTexturedBackground(boolean id0)
    { SetTexturedBackground_127(id0); }

  private native boolean GetTexturedBackground_128();
  public boolean GetTexturedBackground()
    { return GetTexturedBackground_128(); }

  private native void TexturedBackgroundOn_129();
  public void TexturedBackgroundOn()
    { TexturedBackgroundOn_129(); }

  private native void TexturedBackgroundOff_130();
  public void TexturedBackgroundOff()
    { TexturedBackgroundOff_130(); }

  private native void ReleaseGraphicsResources_131(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_131(id0); }

  private native void SetUseFXAA_132(boolean id0);
  public void SetUseFXAA(boolean id0)
    { SetUseFXAA_132(id0); }

  private native boolean GetUseFXAA_133();
  public boolean GetUseFXAA()
    { return GetUseFXAA_133(); }

  private native void UseFXAAOn_134();
  public void UseFXAAOn()
    { UseFXAAOn_134(); }

  private native void UseFXAAOff_135();
  public void UseFXAAOff()
    { UseFXAAOff_135(); }

  private native long GetFXAAOptions_136();
  public vtkFXAAOptions GetFXAAOptions() {
    long temp = GetFXAAOptions_136();

    if (temp == 0) return null;
    return (vtkFXAAOptions)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetFXAAOptions_137(vtkFXAAOptions id0);
  public void SetFXAAOptions(vtkFXAAOptions id0)
    { SetFXAAOptions_137(id0); }

  private native void SetUseShadows_138(int id0);
  public void SetUseShadows(int id0)
    { SetUseShadows_138(id0); }

  private native int GetUseShadows_139();
  public int GetUseShadows()
    { return GetUseShadows_139(); }

  private native void UseShadowsOn_140();
  public void UseShadowsOn()
    { UseShadowsOn_140(); }

  private native void UseShadowsOff_141();
  public void UseShadowsOff()
    { UseShadowsOff_141(); }

  private native void SetUseHiddenLineRemoval_142(int id0);
  public void SetUseHiddenLineRemoval(int id0)
    { SetUseHiddenLineRemoval_142(id0); }

  private native int GetUseHiddenLineRemoval_143();
  public int GetUseHiddenLineRemoval()
    { return GetUseHiddenLineRemoval_143(); }

  private native void UseHiddenLineRemovalOn_144();
  public void UseHiddenLineRemovalOn()
    { UseHiddenLineRemovalOn_144(); }

  private native void UseHiddenLineRemovalOff_145();
  public void UseHiddenLineRemovalOff()
    { UseHiddenLineRemovalOff_145(); }

  private native void SetPass_146(vtkRenderPass id0);
  public void SetPass(vtkRenderPass id0)
    { SetPass_146(id0); }

  private native long GetPass_147();
  public vtkRenderPass GetPass() {
    long temp = GetPass_147();

    if (temp == 0) return null;
    return (vtkRenderPass)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInformation_148();
  public vtkInformation GetInformation() {
    long temp = GetInformation_148();

    if (temp == 0) return null;
    return (vtkInformation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetInformation_149(vtkInformation id0);
  public void SetInformation(vtkInformation id0)
    { SetInformation_149(id0); }

  public vtkRenderer() { super(); }

  public vtkRenderer(long id) { super(id); }
  public native long   VTKInit();

}
